==> haskell-data-functor-logistic-0.0-106-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-functor-logistic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-functor-logistic
version:              0.0
visibility:           public
id:                   data-functor-logistic-0.0-7mGQ434KGoD5NarRqt0tMp
key:                  data-functor-logistic-0.0-7mGQ434KGoD5NarRqt0tMp
license:              BSD-3-Clause
copyright:            Copyright (c) 2021 Fumiaki Kinoshita
maintainer:           fumiexcel@gmail.com
author:               Fumiaki Kinoshita
synopsis:             Updatable analogue of Distributive functors
description:          See README.md
category:             Data Structures
abi:                  7d54934f7d85eca8c690ecb46955df1b
exposed:              True
exposed-modules:      Data.Functor.Logistic
import-dirs:          /usr/lib/ghc-9.4.8/site-local/data-functor-logistic-0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/data-functor-logistic-0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/data-functor-logistic-0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-functor-logistic
hs-libraries:         HSdata-functor-logistic-0.0-7mGQ434KGoD5NarRqt0tMp
depends:
    base-4.17.2.1 distributive-0.6.2.1-Haotoot5pp4Ir9HT1WuuR6

haddock-interfaces:
    /usr/share/doc/haskell-data-functor-logistic/html/data-functor-logistic.haddock

haddock-html:         /usr/share/doc/haskell-data-functor-logistic/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-functor-logistic-0.0-107-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-functor-logistic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-functor-logistic
version:              0.0
visibility:           public
id:                   data-functor-logistic-0.0-JdJSspNUcizGoUIQdk9pPL
key:                  data-functor-logistic-0.0-JdJSspNUcizGoUIQdk9pPL
license:              BSD-3-Clause
copyright:            Copyright (c) 2021 Fumiaki Kinoshita
maintainer:           fumiexcel@gmail.com
author:               Fumiaki Kinoshita
synopsis:             Updatable analogue of Distributive functors
description:          See README.md
category:             Data Structures
abi:                  fb1ff9d4fdfc7213dd743572781e02fc
exposed:              True
exposed-modules:      Data.Functor.Logistic
import-dirs:          /usr/lib/ghc-9.4.8/site-local/data-functor-logistic-0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/data-functor-logistic-0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/data-functor-logistic-0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-functor-logistic
hs-libraries:         HSdata-functor-logistic-0.0-JdJSspNUcizGoUIQdk9pPL
depends:
    base-4.17.2.1 distributive-0.6.2.1-J4m10BQksOFJWoTCKowUeG

haddock-interfaces:
    /usr/share/doc/haskell-data-functor-logistic/html/data-functor-logistic.haddock

haddock-html:         /usr/share/doc/haskell-data-functor-logistic/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
